@@ -1,6 +1,8 @@
 from execelasticsearch.handler import ExecES
 
-es_clients = ExecES(dt=dict(hosts=[{'host': "0.0.0.0"}]))
+config_num = 0
+dt_config = [dict(hosts=[{'host': "0.0.0.0"}]), dict(hosts=[{'host': "0.0.0.0"}], doc_type='tags')][config_num]
+es_clients = ExecES(dt=dt_config)
 
 
 index = 'exec_es_test'
@@ -42,6 +44,11 @@ def es_bulk_delete(data_):
     print(es_clients.bulk_delete(index, ids, hosts))
 
 
+def es_mget(data_, _source_includes=None):
+    ids = [i['id'] for i in data_]
+    print(es_clients.mget(index, ids, hosts, _source_includes=_source_includes))
+
+
 def es_exists(ids: list):
     print(es_clients.exists_ids(index, ids, hosts))
 
